<?php namespace EscapeWork\Manager\Subscribers;

use Eloquent;
use DateTime;

class Subscriber extends Eloquent
{

    /**
     * Tabela
     */
    protected $table = 'subscribers';

    /**
     * Validation rules
     */
    public static $validationRules = array(
        'email' => array('required', 'email'), 
    );

    /**
     * Fillable fields
     */
    public $fillable = array(
        'id', 
        'name', 
        'email', 
        'gender', 
        'born_date', 
        'city', 
        'state', 
        'country', 
        'created_at', 
        'updated_at', 
    );

    /**
     * Setando o sexo
     */
    public function setGenderAttribute($value)
    {
        $accepted = array('m', 'f');

        if (in_array($value, $accepted)) {
            $this->attributes['gender'] = $value;
        }
    }

    /**
     * Setando a data
     */
    public function setBornDateAttribute($value)
    {
        if (! $this->attributes['born_date'] = DateTime::createFromFormat('d/m/Y', $value)) {
            $this->attributes['born_date'] = null;
        }
    }

    /**
     * Setando a cidade
     */
    public function setCityAttribute($value)
    {
        if ($value != '') {
            $this->attributes['city'] = $value;
        }
    }

    /**
     * Setando o estado
     */
    public function setStateAttribute($value)
    {
        if ($value != '') {
            $this->attributes['state'] = $value;
        }
    }

    /**
     * Setando o pais
     */
    public function setCountryAttribute($value)
    {
        if ($value != '') {
            $this->attributes['country'] = $value;
        }
    }

    /**
     * Salvando
     */
    public function save(array $options = array())
    {
        if (! $this->exists && $subscriber = $this->where('email', '=', $this->email)->first()) {
            $this->exists = true;
            $this->id     = $subscriber->id;
        }

        return parent::save($options);
    }
}