<?php namespace EscapeWork\Manager\Subscribers;

use EscapeWork\Manager\Controller\ManagerController;
use View;
use Input;
use Redirect;
use Response;
use Request;

class SubscribersController extends ManagerController
{

    public function __construct()
    {
        $this->subscriber = new Subscriber();

        # filters 
        $this->enableDefaultFilters('subscribers');
    }

    /**
     * Listando os banners
     */
    public function index()
    {
        $view              = View::make('manager-subscribers::subscribers.index');
        $view->subscribers = $this->subscriber->orderBy('created_at', 'desc')->paginate();

        return $view;
    }

    public function create()
    {
        $this->subscriber->fill(Input::old());

        $view             = View::make('manager-subscribers::subscribers.form');
        $view->subscriber = $this->subscriber;
        $view->edit       = false;

        return $view;
    }

    public function store()
    {
        $this->subscriber->fill(Input::all());

        if (! $this->subscriber->validate()) {
            if (Request::ajax()) {
                return Response::json(array(
                    'errors'     => Subscriber::$messages, 
                    'subscriber' => $this->subscriber->toArray(), 
                ));
            } else {
                return Redirect::route('manager.subscribers.create')
                        ->withInput()
                        ->with('errors', Subscriber::$messages);
            }
        }

        $this->subscriber->save();

        if (Request::ajax()) {
            return Response::json(array(
                'message'    => 'Cadastro realizado com sucesso', 
                'subscriber' => $this->subscriber->toArray(), 
            ));
        } else {
            return Redirect::route('manager.subscribers.index')
                    ->with('message', 'O contato <strong>'.$this->subscriber->name.'</strong> foi inserido com sucesso!');
        }
    }

    public function edit($id)
    {
        if (! $this->subscriber = $this->subscriber->find($id)) {
            return Redirect::route('manager.subscribers.index')
                    ->with('error', 'Contato não encontrado');
        }

        $this->subscriber->fill(Input::old());

        $view             = View::make('manager-subscribers::subscribers.form');
        $view->subscriber = $this->subscriber;
        $view->edit       = true;

        return $view;
    }

    public function update($id)
    {
        if (! $this->subscriber = $this->subscriber->find($id)) {
            return Redirect::route('manager.subscribers.index')
                    ->with('error', 'Contato não encontrado');
        }

        $this->subscriber->fill(Input::all());

        if (! $this->subscriber->validate()) {
            return Redirect::route('manager.subscribers.create')
                    ->withInput()
                    ->with('errors', Subscriber::$messages);
        }

        $this->subscriber->save();

        return Redirect::route('manager.subscribers.index')
                        ->with('message', 'O contato <strong>'.$this->subscriber->name.'</strong> foi atualizado com sucesso!');
    }

    public function destroy($id)
    {
        if (! $this->subscriber = $this->subscriber->find($id)) {
            return Redirect::route('manager.subscribers.index')
                    ->with('error', 'Contato não encontrado');
        }

        $this->subscriber->delete();

        return Redirect::route('manager.subscribers.index')
                        ->with('message', 'O contato <strong>'.$this->subscriber->name.'</strong> foi excluído com sucesso!');
    }
}